@@ -3,17 +3,15 @@
 #
 #  (C) Paul Evans, 2010 -- leonerd@leonerd.org.uk
 
-package Tangence;
+package Tangence 0.26;
 
-use strict;
+use v5.14;
 use warnings;
 
 # This package contains no code other than a declaration of the version.
 # It is provided simply to keep CPAN happy:
 #   cpan -i Tangence
 
-our $VERSION = '0.24';
-
 =head1 NAME
 
 C<Tangence> - attribute-oriented server/client object remoting framework
