@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2010-2016 -- leonerd@leonerd.org.uk
 
-package Tangence::Constants;
+package Tangence::Constants 0.26;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.23';
-
 use Exporter 'import';
 our @EXPORT = qw(
    MSG_CALL
