@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2011-2012 -- leonerd@leonerd.org.uk
 
-package Tangence::Meta::Argument;
+package Tangence::Meta::Argument 0.26;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.23';
-
 =head1 NAME
 
 C<Tangence::Meta::Argument> - structure representing one C<Tangence>
@@ -27,7 +25,9 @@ immutable.
 
 =cut
 
-=head2 $argument = Tangence::Meta::Argument->new( %args )
+=head2 new
+
+   $argument = Tangence::Meta::Argument->new( %args )
 
 Returns a new instance initialised by the given arguments.
 
@@ -56,7 +56,9 @@ sub new
 
 =cut
 
-=head2 $name = $argument->name
+=head2 name
+
+   $name = $argument->name
 
 Returns the name of the class
 
@@ -68,7 +70,9 @@ sub name
    return $self->{name};
 }
 
-=head2 $type = $argument->type
+=head2 type
+
+   $type = $argument->type
 
 Return the type as a L<Tangence::Meta::Type> reference.
 
