@@ -1,15 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2017 -- leonerd@leonerd.org.uk
 
-package Tangence::Meta::Event;
+package Tangence::Meta::Event 0.26;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.23';
-
 use Scalar::Util qw( weaken );
 
 =head1 NAME
@@ -27,7 +25,9 @@ event. Once constructed, such objects are immutable.
 
 =cut
 
-=head2 $event = Tangence::Meta::Event->new( %args )
+=head2 new
+
+   $event = Tangence::Meta::Event->new( %args )
 
 Returns a new instance initialised by the given arguments.
 
@@ -64,7 +64,9 @@ sub new
 
 =cut
 
-=head2 $class = $event->class
+=head2 class
+
+   $class = $event->class
 
 Returns the class the event is a member of
 
@@ -76,7 +78,9 @@ sub class
    return $self->{class};
 }
 
-=head2 $name = $event->name
+=head2 name
+
+   $name = $event->name
 
 Returns the name of the class
 
@@ -88,7 +92,9 @@ sub name
    return $self->{name};
 }
 
-=head2 @arguments = $event->arguments
+=head2 arguments
+
+   @arguments = $event->arguments
 
 Return the arguments in a list of L<Tangence::Meta::Argument> references.
 
@@ -100,7 +106,9 @@ sub arguments
    return @{ $self->{arguments} };
 }
 
-=head2 @argtypes = $event->argtypes
+=head2 argtypes
+
+   @argtypes = $event->argtypes
 
 Return the argument types in a list of strings.
 
@@ -119,4 +127,3 @@ Paul Evans <leonerd@leonerd.org.uk>
 =cut
 
 0x55AA;
-
