@@ -1,15 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2012 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2012-2017 -- leonerd@leonerd.org.uk
 
-package Tangence::Meta::Field;
+package Tangence::Meta::Field 0.26;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.24';
-
 =head1 NAME
 
 C<Tangence::Meta::Field> - structure representing one C<Tangence> structure
@@ -26,7 +24,9 @@ structure. Once constructed, such objects are immutable.
 
 =cut
 
-=head2 $field = Tangence::Meta::Field->new( %args )
+=head2 new
+
+   $field = Tangence::Meta::Field->new( %args )
 
 Returns a new instance initialised by the given fields.
 
@@ -55,7 +55,9 @@ sub new
 
 =cut
 
-=head2 $name = $field->name
+=head2 name
+
+   $name = $field->name
 
 Returns the name of the field
 
@@ -67,7 +69,9 @@ sub name
    return $self->{name};
 }
 
-=head2 $type = $field->type
+=head2 type
+
+   $type = $field->type
 
 Return the type as a L<Tangence::Meta::Type> reference.
 
