@@ -1,15 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2017 -- leonerd@leonerd.org.uk
 
-package Tangence::Object;
+package Tangence::Object 0.26;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.23';
-
 use Carp;
 
 use Tangence::Constants;
@@ -75,7 +73,9 @@ sub new
 
 =cut
 
-=head2 $obj->destroy
+=head2 destroy
+
+   $obj->destroy
 
 Requests that the object destroy itself, informing all clients that are aware
 of it. Once they all report that they have dropped the object, the object is
@@ -123,7 +123,9 @@ sub _destroy_really
    $self->{destroyed} = 1;
 }
 
-=head2 $id = $obj->id
+=head2 id
+
+   $id = $obj->id
 
 Returns the object's C<Tangence> ID number
 
@@ -135,7 +137,9 @@ sub id
    return $self->{id};
 }
 
-=head2 $description = $obj->describe
+=head2 describe
+
+   $description = $obj->describe
 
 Returns a textual description of the object, for internal debugging purposes.
 Subclasses are encouraged to override this method to return something more
@@ -149,7 +153,9 @@ sub describe
    return ref $self;
 }
 
-=head2 $registry = $obj->registry
+=head2 registry
+
+   $registry = $obj->registry
 
 Returns the L<Tangence::Registry> that constructed this object.
 
@@ -182,7 +188,9 @@ sub smash
    } @keys };
 }
 
-=head2 $class = $obj->class
+=head2 class
+
+   $class = $obj->class
 
 Returns the L<Tangence::Meta::Class> object representing the class of this
 object.
@@ -195,7 +203,9 @@ sub class
    return ref $self ? $self->{meta} : Tangence::Class->for_perlname( $self );
 }
 
-=head2 $method = $obj->can_method( $name )
+=head2 can_method
+
+   $method = $obj->can_method( $name )
 
 Returns the L<Tangence::Meta::Method> object representing the named method, or
 C<undef> if no such method exists.
@@ -208,7 +218,9 @@ sub can_method
    return $self->class->method( @_ );
 }
 
-=head2 $event = $obj->can_event( $name )
+=head2 can_event
+
+   $event = $obj->can_event( $name )
 
 Returns the L<Tangence::Meta::Event> object representing the named event, or
 C<undef> if no such event exists.
@@ -221,7 +233,9 @@ sub can_event
    return $self->class->event( @_ );
 }
 
-=head2 $property = $obj->can_property( $name )
+=head2 can_property
+
+   $property = $obj->can_property( $name )
 
 Returns the L<Tangence::Meta::Property> object representing the named
 property, or C<undef> if no such property exists.
@@ -240,7 +254,9 @@ sub smashkeys
    return $self->class->smashkeys;
 }
 
-=head2 $obj->fire_event( $event, @args )
+=head2 fire_event
+
+   $obj->fire_event( $event, @args )
 
 Fires the named event on the object. Each event subscription function will be
 invoked with the given arguments.
@@ -263,13 +279,15 @@ sub fire_event
    }
 }
 
-=head2 $id = $obj->subscribe_event( $event, $callback )
+=head2 subscribe_event
+
+   $id = $obj->subscribe_event( $event, $callback )
 
 Subscribes an event-handling callback CODE ref to the named event. When the
 event is fired by C<fire_event> this callback will be invoked, being passed
 the object reference and the event's arguments.
 
- $callback->( $obj, @args )
+   $callback->( $obj, @args )
 
 Returns an opaque ID value that can be used to remove this subscription by
 calling C<unsubscribe_event>.
@@ -291,7 +309,9 @@ sub subscribe_event
    return $ref + 0; # force numeric context
 }
 
-=head2 $obj->unsubscribe_event( $event, $id )
+=head2 unsubscribe_event
+
+   $obj->unsubscribe_event( $event, $id )
 
 Removes an event-handling callback previously registered with
 C<subscribe_event>.
@@ -313,7 +333,9 @@ sub unsubscribe_event
    splice @$sublist, $index, 1, ();
 }
 
-=head2 $id = $obj->watch_property( $prop, %callbacks )
+=head2 watch_property
+
+   $id = $obj->watch_property( $prop, %callbacks )
 
 Watches a named property for changes, registering a set of callback functions
 to be invoked when the property changes in certain ways. The set of callbacks
@@ -321,34 +343,34 @@ required depends on the dimension of the property being watched.
 
 For all property types:
 
- $on_set->( $obj, $value )
+   $on_set->( $obj, $value )
 
 For hash properties:
 
- $on_add->( $obj, $key, $value )
- $on_del->( $obj, $key )
+   $on_add->( $obj, $key, $value )
+   $on_del->( $obj, $key )
 
 For queue properties:
 
- $on_push->( $obj, @values )
- $on_shift->( $obj, $count )
+   $on_push->( $obj, @values )
+   $on_shift->( $obj, $count )
 
 For array properties:
 
- $on_push->( $obj, @values )
- $on_shift->( $obj, $count )
- $on_splice->( $obj, $index, $count, @values )
- $on_move->( $obj, $index, $delta )
+   $on_push->( $obj, @values )
+   $on_shift->( $obj, $count )
+   $on_splice->( $obj, $index, $count, @values )
+   $on_move->( $obj, $index, $delta )
 
 For objset properties:
 
- $on_add->( $obj, $added_object )
- $on_del->( $obj, $deleted_object_id )
+   $on_add->( $obj, $added_object )
+   $on_del->( $obj, $deleted_object_id )
 
 Alternatively, a single callback may be installed that is invoked after any
 change of the property, being passed the new value entirely:
 
- $on_updated->( $obj, $value )
+   $on_updated->( $obj, $value )
 
 Returns an opaque ID value that can be used to remove this watch by calling
 C<unwatch_property>.
@@ -388,7 +410,9 @@ sub watch_property
    return $ref + 0; # force numeric context
 }
 
-=head2 $obj->unwatch_property( $prop, $id )
+=head2 unwatch_property
+
+   $obj->unwatch_property( $prop, $id )
 
 Removes the set of callback functions previously registered with
 C<watch_property>.
@@ -512,7 +536,7 @@ sub handle_request_SETPROP
 
    my $pdef = $self->can_property( $prop ) or die "Object does not have property $prop\n";
 
-   my $value = $pdef->type->unpack_value( $message );
+   my $value = $pdef->overall_type->unpack_value( $message );
 
    my $m = "set_prop_$prop";
    $self->can( $m ) or die "Object cannot set property $prop\n";
