@@ -1,15 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2020 -- leonerd@leonerd.org.uk
 
-package Tangence::ObjectProxy;
+package Tangence::ObjectProxy 0.26;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.23';
-
 use Carp;
 
 use Tangence::Constants;
@@ -269,7 +267,7 @@ Takes the following named callbacks:
 
 Callback function to invoke whenever the event is fired
 
- $on_fire->( @args )
+   $on_fire->( @args )
 
 The returned C<Future> it is guaranteed to be completed before any invocation
 of the C<on_fire> event handler.
@@ -427,7 +425,6 @@ sub get_property_element
       or croak "Class ".$self->classname." does not have a property $property";
 
    my $client = $self->{client};
-   $client->_ver_can_getpropelem or croak "Server is too old to support MSG_GETPROPELEM";
 
    my $request = Tangence::Message->new( $client, MSG_GETPROPELEM )
       ->pack_int( $self->id )
@@ -504,7 +501,7 @@ sub set_property
    my $request = Tangence::Message->new( $client, MSG_SETPROP )
          ->pack_int( $self->id )
          ->pack_str( $property );
-   $pdef->type->pack_value( $request, $value ),
+   $pdef->overall_type->pack_value( $request, $value );
 
    $client->request(
       request => $request,
@@ -543,7 +540,7 @@ Takes the following named arguments:
 
 Optional. Callback function to invoke whenever the property value changes.
 
- $on_updated->( $new_value )
+   $on_updated->( $new_value )
 
 If not provided, then individual handlers for individual change types must be
 provided.
@@ -708,7 +705,7 @@ sub watch_property_with_cursor
    my $smashed = $pdef->smashed;
 
    if( my $cbs = $self->{props}->{$property}->{cbs} ) {
-      die "TODO: need to synthesize a second cursor";
+      die "TODO: need to synthesize a second cursor for $self";
    }
 
    $self->{props}->{$property}->{cbs} = [ $callbacks ];
@@ -718,7 +715,6 @@ sub watch_property_with_cursor
    }
 
    my $client = $self->{client};
-   $client->_ver_can_cursor or croak "Server is too old to support MSG_WATCH_CUSR";
    $pdef->dimension == DIM_QUEUE or croak "Can only iterate on queue-dimension properties";
 
    $client->request(
