@@ -1,20 +1,20 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2020 -- leonerd@leonerd.org.uk
 
-package Tangence::Server;
+package Tangence::Server 0.26;
 
-use strict;
+use v5.14;
 use warnings;
 
 use base qw( Tangence::Stream );
 
-our $VERSION = '0.24';
-
 use Carp;
 
 use Scalar::Util qw( weaken );
+use Sub::Util 1.40 qw( set_subname );
+use Feature::Compat::Try;
 
 use Tangence::Constants;
 use Tangence::Types;
@@ -23,18 +23,8 @@ use Tangence::Server::Context;
 use Struct::Dumb;
 struct CursorObject => [qw( cursor obj )];
 
-# We will accept any version back to 2
-use constant VERSION_MINOR_MIN => 2;
-
-BEGIN {
-   if( eval { require Sub::Name } ) {
-      Sub::Name->import(qw( subname ));
-   }
-   else {
-      # Emulate it by just returning the CODEref and ignoring setting the name
-      *subname = sub { $_[1] };
-   }
-}
+# We will accept any version back to 3
+use constant VERSION_MINOR_MIN => 3;
 
 =head1 NAME
 
@@ -44,34 +34,34 @@ C<Tangence::Server> - mixin class for building a C<Tangence> server
 
 This class is a mixin, it cannot be directly constructed
 
- package Example::Server;
- use base qw( Base::Server Tangence::Server );
+   package Example::Server;
+   use base qw( Base::Server Tangence::Server );
 
- sub new
- {
-    my $class = shift;
-    my %args = @_;
+   sub new
+   {
+      my $class = shift;
+      my %args = @_;
 
-    my $registry = delete $args{registry};
+      my $registry = delete $args{registry};
 
-    my $self = $class->SUPER::new( %args );
+      my $self = $class->SUPER::new( %args );
 
-    $self->registry( $registry );
+      $self->registry( $registry );
 
-    return $self;
- }
+      return $self;
+   }
 
- sub tangence_write
- {
-    my $self = shift;
-    $self->write( $_[0] );
- }
+   sub tangence_write
+   {
+      my $self = shift;
+      $self->write( $_[0] );
+   }
 
- sub on_read
- {
-    my $self = shift;
-    $self->tangence_readfrom( $_[0] );
- }
+   sub on_read
+   {
+      my $self = shift;
+      $self->tangence_readfrom( $_[0] );
+   }
 
 =head1 DESCRIPTION
 
@@ -100,9 +90,11 @@ The following methods are provided by this mixin.
 sub subscriptions { shift->{subscriptions} ||= [] }
 sub watches       { shift->{watches} ||= [] }
 
-=head2 $server->registry( $registry )
+=head2 registry
 
-=head2 $registry = $server->registry
+   $server->registry( $registry )
+
+   $registry = $server->registry
 
 Accessor to set or obtain the L<Tangence::Registry> object for the server.
 
@@ -150,23 +142,35 @@ sub get_by_id
    my $self = shift;
    my ( $id ) = @_;
 
-   return $self->registry->get_by_id( $id );
+   # Only permit the client to interact with objects they've already been
+   # sent, so they cannot gain access by inventing object IDs
+   $self->peer_hasobj->{$id} or
+      die "Access not allowed to object with id $id\n";
+
+   my $obj = $self->registry->get_by_id( $id ) or
+      die "No such object with id $id\n";
+
+   return $obj;
 }
 
 sub handle_request_CALL
 {
    my $self = shift;
    my ( $token, $message ) = @_;
-   
-   my $objid = $message->unpack_int();
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $object = $self->registry->get_by_id( $objid ) or
-      return $ctx->responderr( "No such object with id $objid" );
+   my $response;
+   try {
+      my $objid = $message->unpack_int();
 
-   my $response = eval { $object->handle_request_CALL( $ctx, $message ) };
-   $@ and return $ctx->responderr( $@ );
+      my $object = $self->get_by_id( $objid );
+
+      $response = $object->handle_request_CALL( $ctx, $message );
+   }
+   catch ( $e ) {
+      return $ctx->responderr( $e );
+   }
 
    $ctx->respond( $response );
 }
@@ -175,77 +179,95 @@ sub handle_request_SUBSCRIBE
 {
    my $self = shift;
    my ( $token, $message ) = @_;
-   
-   my $objid = $message->unpack_int();
-   my $event = $message->unpack_str();
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $object = $self->registry->get_by_id( $objid ) or
-      return $ctx->responderr( "No such object with id $objid" );
+   my $response;
+   try {
+      my $objid = $message->unpack_int();
+      my $event = $message->unpack_str();
 
-   weaken( my $weakself = $self );
+      my $object = $self->get_by_id( $objid );
 
-   my $id = $object->subscribe_event( $event,
-      subname "__SUBSCRIBE($event)__" => sub {
-         $weakself or return;
-         my $object = shift;
+      weaken( my $weakself = $self );
 
-         my $message = $object->generate_message_EVENT( $weakself, $event, @_ );
-         $weakself->request(
-            request     => $message,
-            on_response => sub { "IGNORE" },
-         );
-      }
-   );
+      my $id = $object->subscribe_event( $event,
+         set_subname "__SUBSCRIBE($event)__" => sub {
+            $weakself or return;
+            my $object = shift;
 
-   push @{ $self->subscriptions }, [ $object, $event, $id ];
+            my $message = $object->generate_message_EVENT( $weakself, $event, @_ );
+            $weakself->request(
+               request     => $message,
+               on_response => sub { "IGNORE" },
+            );
+         }
+      );
 
-   $ctx->respond( Tangence::Message->new( $self, MSG_SUBSCRIBED ) );
+      push @{ $self->subscriptions }, [ $object, $event, $id ];
+
+      $response = Tangence::Message->new( $self, MSG_SUBSCRIBED )
+   }
+   catch ( $e ) {
+      return $ctx->responderr( $e );
+   }
+
+   $ctx->respond( $response );
 }
 
 sub handle_request_UNSUBSCRIBE
 {
    my $self = shift;
    my ( $token, $message ) = @_;
-   
-   my $objid = $message->unpack_int();
-   my $event = $message->unpack_str();
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $object = $self->registry->get_by_id( $objid ) or
-      return $ctx->responderr( "No such object with id $objid" );
+   my $response;
+   try {
+      my $objid = $message->unpack_int();
+      my $event = $message->unpack_str();
 
-   my $edef = $object->can_event( $event ) or
-      return $ctx->responderr( "Object cannot respond to event $event" );
+      my $object = $self->get_by_id( $objid );
 
-   # Delete from subscriptions and obtain id
-   my $id;
-   @{ $self->subscriptions } = grep { $_->[0] == $object and $_->[1] eq $event and ( $id = $_->[2], 0 ) or 1 }
-                                 @{ $self->subscriptions };
-   defined $id or
-      return $ctx->responderr( "Not subscribed to $event" );
+      my $edef = $object->can_event( $event ) or
+         die "Object cannot respond to event $event\n";
 
-   $object->unsubscribe_event( $event, $id );
+      # Delete from subscriptions and obtain id
+      my $id;
+      @{ $self->subscriptions } = grep { $_->[0] == $object and $_->[1] eq $event and ( $id = $_->[2], 0 ) or 1 }
+                                     @{ $self->subscriptions };
+      defined $id or
+         die "Not subscribed to $event\n";
 
-   $ctx->respond( Tangence::Message->new( $self, MSG_OK ) );
+      $object->unsubscribe_event( $event, $id );
+
+      $response = Tangence::Message->new( $self, MSG_OK )
+   }
+   catch ( $e ) {
+      return $ctx->responderr( $e );
+   }
+
+   $ctx->respond( $response );
 }
 
 sub handle_request_GETPROP
 {
    my $self = shift;
    my ( $token, $message ) = @_;
-   
-   my $objid = $message->unpack_int();
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $object = $self->registry->get_by_id( $objid ) or
-      return $ctx->responderr( "No such object with id $objid" );
+   my $response;
+   try {
+      my $objid = $message->unpack_int();
 
-   my $response = eval { $object->handle_request_GETPROP( $ctx, $message ) };
-   $@ and return $ctx->responderr( $@ );
+      my $object = $self->get_by_id( $objid );
+
+      $response = $object->handle_request_GETPROP( $ctx, $message )
+   }
+   catch ( $e ) {
+      return $ctx->responderr( $e );
+   }
 
    $ctx->respond( $response );
 }
@@ -255,15 +277,19 @@ sub handle_request_GETPROPELEM
    my $self = shift;
    my ( $token, $message ) = @_;
 
-   my $objid = $message->unpack_int();
-
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $object = $self->registry->get_by_id( $objid ) or
-      return $ctx->responderr( "No such object with id $objid" );
+   my $response;
+   try {
+      my $objid = $message->unpack_int();
 
-   my $response = eval { $object->handle_request_GETPROPELEM( $ctx, $message ) };
-   $@ and return $ctx->responderr( $@ );
+      my $object = $self->get_by_id( $objid );
+
+      $response = $object->handle_request_GETPROPELEM( $ctx, $message )
+   }
+   catch ( $e ) {
+      return $ctx->responderr( $e );
+   }
 
    $ctx->respond( $response );
 }
@@ -272,16 +298,20 @@ sub handle_request_SETPROP
 {
    my $self = shift;
    my ( $token, $message ) = @_;
-   
-   my $objid = $message->unpack_int();
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $object = $self->registry->get_by_id( $objid ) or
-      return $ctx->responderr( "No such object with id $objid" );
+   my $response;
+   try {
+      my $objid = $message->unpack_int();
 
-   my $response = eval { $object->handle_request_SETPROP( $ctx, $message ) };
-   $@ and return $ctx->responderr( $@ );
+      my $object = $self->get_by_id( $objid );
+
+      $response = $object->handle_request_SETPROP( $ctx, $message )
+   }
+   catch ( $e ) {
+      return $ctx->responderr( $e );
+   }
 
    $ctx->respond( $response );
 }
@@ -292,43 +322,49 @@ sub _handle_request_WATCHany
 {
    my $self = shift;
    my ( $token, $message ) = @_;
-   
-   my $objid = $message->unpack_int();
-   my $prop  = $message->unpack_str();
-   my $want_initial;
-   my $from;
-   if( $message->code == MSG_WATCH ) {
-      $want_initial = $message->unpack_bool();
-   }
-   elsif( $message->code == MSG_WATCH_CUSR ) {
-      $from = $message->unpack_int();
-   }
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $object = $self->registry->get_by_id( $objid ) or
-      return $ctx->responderr( "No such object with id $objid" );
+   my ( $want_initial, $object, $prop );
 
-   my $pdef = $object->can_property( $prop ) or
-      return $ctx->responderr( "Object does not have property $prop" );
+   my $response;
+   try {
+      my $objid = $message->unpack_int();
+      $prop     = $message->unpack_str();
 
-   $self->_install_watch( $object, $prop );
+      $object = $self->get_by_id( $objid );
 
-   if( $message->code == MSG_WATCH ) {
-      $ctx->respond( Tangence::Message->new( $self, MSG_WATCHING ) );
-      $self->_send_initial( $object, $prop ) if $want_initial;
+      my $pdef = $object->can_property( $prop ) or
+         die "Object does not have property $prop\n";
+
+      $self->_install_watch( $object, $prop );
+
+      if( $message->code == MSG_WATCH ) {
+         $want_initial = $message->unpack_bool();
+
+         $response = Tangence::Message->new( $self, MSG_WATCHING )
+      }
+      elsif( $message->code == MSG_WATCH_CUSR ) {
+         my $from = $message->unpack_int();
+
+         my $m = "cursor_prop_$prop";
+         my $cursor = $object->$m( $from );
+         my $id = $self->message_state->{next_cursorid}++;
+
+         $self->peer_hascursor->{$id} = CursorObject( $cursor, $object );
+         $response = Tangence::Message->new( $self, MSG_WATCHING_CUSR )
+            ->pack_int( $id )
+            ->pack_int( 0 ) # first index
+            ->pack_int( $#{ $object->${\"get_prop_$prop"} } ) # last index
+      }
    }
-   elsif( $message->code == MSG_WATCH_CUSR ) {
-      my $m = "cursor_prop_$prop";
-      my $cursor = $object->$m( $from );
-      my $id = $self->message_state->{next_cursorid}++;
-      $self->peer_hascursor->{$id} = CursorObject( $cursor, $object );
-      $ctx->respond( Tangence::Message->new( $self, MSG_WATCHING_CUSR )
-         ->pack_int( $id )
-         ->pack_int( 0 ) # first index
-         ->pack_int( $#{ $object->${\"get_prop_$prop"} } ) # last index
-      );
+   catch ( $e ) {
+      return $ctx->responderr( $e );
    }
+
+   $ctx->respond( $response );
+
+   $self->_send_initial( $object, $prop ) if $want_initial;
 }
 
 sub _send_initial
@@ -339,43 +375,52 @@ sub _send_initial
    my $m = "get_prop_$prop";
    return unless( $object->can( $m ) );
 
-   eval {
+   try {
       my $value = $object->$m();
       my $message = $object->generate_message_UPDATE( $self, $prop, CHANGE_SET, $value );
       $self->request(
          request     => $message,
          on_response => sub { "IGNORE" },
       );
-   };
-   warn "$@ during initial property fetch" if $@;
+   }
+   catch ( $e ) {
+      warn "$e during initial property fetch";
+   }
 }
 
 sub handle_request_UNWATCH
 {
    my $self = shift;
    my ( $token, $message ) = @_;
-   
-   my $objid = $message->unpack_int();
-   my $prop  = $message->unpack_str();
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $object = $self->registry->get_by_id( $objid ) or
-      return $ctx->responderr( "No such object with id $objid" );
+   my $response;
+   try {
+      my $objid = $message->unpack_int();
+      my $prop  = $message->unpack_str();
 
-   my $pdef = $object->can_property( $prop ) or
-      return $ctx->responderr( "Object does not have property $prop" );
+      my $object = $self->get_by_id( $objid );
 
-   # Delete from watches and obtain id
-   my $id;
-   @{ $self->watches } = grep { $_->[0] == $object and $_->[1] eq $prop and ( $id = $_->[2], 0 ) or 1 }
-                         @{ $self->watches };
-   defined $id or
-      return $ctx->responderr( "Not watching $prop" );
+      my $pdef = $object->can_property( $prop ) or
+         die "Object does not have property $prop\n";
 
-   $object->unwatch_property( $prop, $id );
+      # Delete from watches and obtain id
+      my $id;
+      @{ $self->watches } = grep { $_->[0] == $object and $_->[1] eq $prop and ( $id = $_->[2], 0 ) or 1 }
+                            @{ $self->watches };
+      defined $id or
+         die "Not watching $prop\n";
 
-   $ctx->respond( Tangence::Message->new( $self, MSG_OK ) );
+      $object->unwatch_property( $prop, $id );
+
+      $response = Tangence::Message->new( $self, MSG_OK );
+   }
+   catch ( $e ) {
+      return $ctx->responderr( $e );
+   }
+
+   $ctx->respond( $response );
 }
 
 sub handle_request_CUSR_NEXT
@@ -461,10 +506,10 @@ sub handle_request_GETROOT
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $root = $self->registry->get_by_id( 1 );
-
    $self->identity( $identity );
 
+   my $root = $self->rootobj( $identity );
+
    my $response = Tangence::Message->new( $self, MSG_RESULT );
    TYPE_OBJ->pack_value( $response, $root );
 
@@ -478,6 +523,9 @@ sub handle_request_GETREGISTRY
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
+   $self->permit_registry or
+      return $ctx->responderr( "This client is not permitted access to the registry" );
+
    my $response = Tangence::Message->new( $self, MSG_RESULT );
    TYPE_OBJ->pack_value( $response, $self->registry );
 
@@ -507,7 +555,7 @@ sub _install_watch
    my %callbacks;
    foreach my $name ( @{ CHANGETYPES->{$dim} } ) {
       my $how = $change_values{$name};
-      $callbacks{$name} = subname "__WATCH($prop:$name)__" => sub {
+      $callbacks{$name} = set_subname "__WATCH($prop:$name)__" => sub {
          $weakself or return;
          my $object = shift;
 
@@ -562,6 +610,50 @@ sub object_destroyed
    $self->SUPER::object_destroyed( @_ );
 }
 
+=head1 OVERRIDEABLE METHODS
+
+The following methods are provided but intended to be overridden if the
+implementing class wishes to provide different behaviour from the default.
+
+=cut
+
+=head2 rootobj
+
+   $rootobj = $server->rootobj( $identity )
+
+Invoked when a C<GETROOT> message is received from the client, this method
+should return a L<Tangence::Object> as root object for the connection.
+
+The default implementation will return the object with ID 1; i.e. the first
+object created in the registry.
+
+=cut
+
+sub rootobj
+{
+   my $self = shift;
+
+   return $self->registry->get_by_id( 1 );
+}
+
+=head2 permit_registry
+
+   $allow = $server->permit_registry
+
+Invoked when a C<GETREGISTRY> message is received from the client, this method
+should return a boolean to indicate whether the client is allowed to access
+the object registry.
+
+The default implementation always permits this, but an overridden method may
+decide to disallow it in some situations. When disabled, a client will not be
+able to gain access to any serverside objects other than the root object, and
+(recursively) any other objects returned by methods, events or properties on
+objects already known. This can be used as a security mechanism.
+
+=cut
+
+sub permit_registry { 1; }
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
