@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2010-2011 -- leonerd@leonerd.org.uk
 
-package Tangence::Server::Context;
+package Tangence::Server::Context 0.26;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.23';
-
 use Carp;
 
 use Tangence::Constants;
@@ -56,6 +54,8 @@ sub responderr
    my $self = shift;
    my ( $msg ) = @_;
 
+   chomp $msg; # In case of simple  ->responderr( $@ );
+
    $self->respond( Tangence::Message->new( $self->stream, MSG_ERROR )
       ->pack_str( $msg )
    );
