@@ -1,32 +1,11 @@
 package t::Ball;
 
-use strict;
+use v5.14;
 
 use base qw( Tangence::Object t::Colourable );
 
 use Tangence::Constants;
 
-our %METHODS = (
-   bounce => {
-      args => [qw( str )],
-      ret  => 'str',
-   },
-);
-
-our %EVENTS = (
-   bounced => {
-      args => [qw( str )],
-   },
-);
-
-our %PROPS = (
-   size => {
-      dim  => DIM_SCALAR,
-      type => 'int',
-      smash => 1,
-   },
-);
-
 sub new
 {
    my $class = shift;
@@ -34,8 +13,8 @@ sub new
 
    my $self = $class->SUPER::new( %args );
 
-   $self->set_prop_colour( $args{colour} );
-   $self->set_prop_size( $args{size} );
+   $self->set_prop_colour( $args{colour} ) if defined $args{colour};
+   $self->set_prop_size( $args{size} ) if defined $args{size};
 
    return $self;
 }
