@@ -1,6 +1,6 @@
 package t::Conversation;
 
-use strict;
+use v5.14;
 use warnings;
 
 use Exporter 'import';
@@ -28,21 +28,21 @@ our $MSG_OK = "\x80" . "\0\0\0\0";
 $C2S{INIT} =
    "\x7f" . "\0\0\0\6" .
    "\x02" . "\0" .
-   "\x02" . "\3" .
-   "\x02" . "\2";
+   "\x02" . "\4" .
+   "\x02" . "\3";
 
 # MSG_INITED
 $S2C{INITED} =
    "\xff" . "\0\0\0\4" .
    "\x02" . "\0" .
-   "\x02" . "\3";
+   "\x02" . "\4";
 
 # MSG_GETROOT
 $C2S{GETROOT} = 
    "\x40" . "\0\0\0\x0b" .
    "\x2a" . "testscript";
 $S2C{GETROOT} =
-   "\x82" . "\0\0\0\xde" .
+   "\x82" . "\0\0\0\xf8" .
    "\xe2" . "\x29t.TestObj" .
             "\x02\1" .
             "\xa4" . "\x02\1" .
@@ -56,7 +56,7 @@ $S2C{GETROOT} =
                      "\x61" . "\x25event" . "\xa1" . "\x02\3" .
                                                      "\x42" . "\x23int" .
                                                               "\x23str" .
-                     "\x67" . "\x25array" . "\xa3" . "\x02\4" .
+                     "\x68" . "\x25array" . "\xa3" . "\x02\4" .
                                                      "\x02\4" .
                                                      "\x23int" .
                                                      "\x00" .
@@ -76,6 +76,10 @@ $S2C{GETROOT} =
                                                      "\x02\3" .
                                                      "\x23int" .
                                                      "\x00" .
+                              "\x27s_array" . "\xa3" . "\x02\4" .
+                                                       "\x02\4" .
+                                                       "\x23int" .
+                                                       "\x01" .
                               "\x28s_scalar" . "\xa3" . "\x02\4" .
                                                         "\x02\1" .
                                                         "\x23int" .
@@ -85,10 +89,12 @@ $S2C{GETROOT} =
                                                       "\x23int" .
                                                       "\x00" .
                      "\x40" .
-            "\x41" . "\x28s_scalar" .
+            "\x42" . "\x27s_array" .
+                     "\x28s_scalar" .
    "\xe1" . "\x02\1" .
             "\x02\1" .
-            "\x41" . "\x23456" . # TODO: should be \x04..
+            "\x42" . "\x40" .
+                     "\x04\x01\xc8" .
    "\x84" . "\0\0\0\1";
 
 # MSG_GETREGISTRY
